@@ -478,13 +478,14 @@ returns true if this node is in maintenance mode.
 sub maint {
     my($self, $node, $val) = @_;
     my $c = $Thruk::Utils::Cluster::context;
+    $c->cluster->load_statefile(); # update current state, it is cached usually
     $node = $c->cluster->{'node'} unless defined $node;
     my $old = $node->{'maintenance'} || 0;
     if(defined $val) {
         confess("cluster not ready") unless($node && $node->{'node_id'});
         # is that us?
         if($self->is_it_me($node)) {
-            # save to both files, otherwise information would be lost after an omd update where the tmp fs might be remountet
+            # save to both files, otherwise information would be lost after an omd update where the tmp fs might be remounted
             for my $file ($self->{'registerfile'}, $self->{'localstate'}) {
                 Thruk::Utils::IO::json_lock_patch($file, {
                     $node->{'node_id'} => {
